==> tdesdk-trinity_14.0.4.orig.tar.xz: tdesdk-trinity-14.0.4/kbabel/commonui/toolselectionwidget.h <==
/* This file is part of KBabel
   Copyright (C) 2002 Stanislav Visnovsky <visnovsky@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.

  In addition, as a special exception, the copyright holders give
  permission to link the code of this program with any edition of
  the TQt library by Trolltech AS, Norway (or with modified versions
  of TQt that use the same license as TQt), and distribute linked
  combinations including the two.  You must obey the GNU General
  Public License in all respects for all of the code used other than
  TQt. If you modify this file, you may extend this exception to
  your version of the file, but you are not obligated to do so.  If
  you do not wish to do so, delete this exception statement from
  your version.

*/

#ifndef TOOLSELECTIONWIDGET_H
#define TOOLSELECTIONWIDGET_H

#include "tdeactionselector.h"
#include <kdemacros.h>

class KDataToolInfo;

class KDE_EXPORT ToolSelectionWidget : public TDEActionSelector
{
    Q_OBJECT
  
public:
    ToolSelectionWidget(TQWidget* parent=0, const char* name=0 );
	
    TQStringList selectedTools();
    
    void loadTools (const TQStringList& commands, const TQValueList<KDataToolInfo> & tools);

public slots:
    void setSelectedTools( const TQStringList& tools );
    
private:
    TQValueList<KDataToolInfo> _allTools;
};

#endif

==> tdesdk-trinity-14.1.5.tar.xz: tdesdk-trinity-14.1.5/kbabel/commonui/toolselectionwidget.h <==
/* This file is part of KBabel
   Copyright (C) 2002 Stanislav Visnovsky <visnovsky@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.

  In addition, as a special exception, the copyright holders give
  permission to link the code of this program with any edition of
  the TQt library by Trolltech AS, Norway (or with modified versions
  of TQt that use the same license as TQt), and distribute linked
  combinations including the two.  You must obey the GNU General
  Public License in all respects for all of the code used other than
  TQt. If you modify this file, you may extend this exception to
  your version of the file, but you are not obligated to do so.  If
  you do not wish to do so, delete this exception statement from
  your version.

*/

#ifndef TOOLSELECTIONWIDGET_H
#define TOOLSELECTIONWIDGET_H

#include "tdeactionselector.h"
#include <tdemacros.h>

class KDataToolInfo;

class TDE_EXPORT ToolSelectionWidget : public TDEActionSelector
{
    TQ_OBJECT
  
public:
    ToolSelectionWidget(TQWidget* parent=0, const char* name=0 );
	
    TQStringList selectedTools();
    
    void loadTools (const TQStringList& commands, const TQValueList<KDataToolInfo> & tools);

public slots:
    void setSelectedTools( const TQStringList& tools );
    
private:
    TQValueList<KDataToolInfo> _allTools;
};

#endif
